You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2010/05/23 17:39:31 UTC

svn commit: r947432 - in /subversion/trunk/subversion: include/svn_client.h include/svn_diff.h libsvn_diff/parse-diff.c svn/cl.h svn/main.c svn/patch-cmd.c tests/cmdline/merge_tests.py tests/cmdline/patch_tests.py tests/libsvn_diff/parse-diff-test.c

Author: stsp
Date: Sun May 23 15:39:31 2010
New Revision: 947432

URL: http://svn.apache.org/viewvc?rev=947432&view=rev
Log:
* subversion/include/svn_client.h,
  subversion/include/svn_diff.h,
  subversion/libsvn_diff/parse-diff.c,
  subversion/svn/cl.h,
  subversion/svn/main.c,
  subversion/svn/patch-cmd.c,
  subversion/tests/cmdline/merge_tests.py,
  subversion/tests/cmdline/patch_tests.py,
  subversion/tests/libsvn_diff/parse-diff-test.c:
   Do the following global search/replace: "s/whitespaces/whitespace/g".
   This includes occurrences in variable names, CLI client option names,
   function names, docstrings, and comments.

Modified:
    subversion/trunk/subversion/include/svn_client.h
    subversion/trunk/subversion/include/svn_diff.h
    subversion/trunk/subversion/libsvn_diff/parse-diff.c
    subversion/trunk/subversion/svn/cl.h
    subversion/trunk/subversion/svn/main.c
    subversion/trunk/subversion/svn/patch-cmd.c
    subversion/trunk/subversion/tests/cmdline/merge_tests.py
    subversion/trunk/subversion/tests/cmdline/patch_tests.py
    subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c

Modified: subversion/trunk/subversion/include/svn_client.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_diff/parse-diff.c (original)
+++ subversion/trunk/subversion/libsvn_diff/parse-diff.c Sun May 23 15:39:31 2010
@@ -269,7 +269,7 @@ parse_next_hunk(svn_hunk_t **hunk,
                 svn_patch_t *patch,
                 svn_stream_t *stream,
                 svn_boolean_t reverse,
-                svn_boolean_t ignore_whitespaces,
+                svn_boolean_t ignore_whitespace,
                 apr_pool_t *result_pool,
                 apr_pool_t *scratch_pool)
 {
@@ -360,7 +360,7 @@ parse_next_hunk(svn_hunk_t **hunk,
           if (original_lines > 0 && modified_lines > 0 
               && ((c == ' ')
               || (! eof && line->len == 0)
-              || (ignore_whitespaces && c != del && c != add)))
+              || (ignore_whitespace && c != del && c != add)))
             {
               hunk_seen = TRUE;
               original_lines--;
@@ -521,7 +521,7 @@ svn_error_t *
 svn_diff_parse_next_patch(svn_patch_t **patch,
                           apr_file_t *patch_file,
                           svn_boolean_t reverse,
-                          svn_boolean_t ignore_whitespaces,
+                          svn_boolean_t ignore_whitespace,
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool)
 {
@@ -629,7 +629,7 @@ svn_diff_parse_next_patch(svn_patch_t **
           svn_pool_clear(iterpool);
 
           SVN_ERR(parse_next_hunk(&hunk, *patch, stream, reverse,
-                                  ignore_whitespaces, result_pool, iterpool));
+                                  ignore_whitespace, result_pool, iterpool));
           if (hunk)
             APR_ARRAY_PUSH((*patch)->hunks, svn_hunk_t *) = hunk;
         }

Modified: subversion/trunk/subversion/svn/cl.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/cl.h?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/main.c (original)
+++ subversion/trunk/subversion/svn/main.c Sun May 23 15:39:31 2010
@@ -119,7 +119,7 @@ typedef enum {
   opt_reverse_diff,
   opt_include_pattern,
   opt_exclude_pattern,
-  opt_ignore_whitespaces,
+  opt_ignore_whitespace,
   opt_show_diff,
 } svn_cl__longopt_t;
 
@@ -381,8 +381,8 @@ const apr_getopt_option_t svn_cl__option
                        "See also the --include-pattern option.\n"
                        "                             "
                        "[alias: --ep]")},
-  {"ignore-whitespaces", opt_ignore_whitespaces, 0,
-                       N_("don't take whitespaces into account when,\n"
+  {"ignore-whitespace", opt_ignore_whitespace, 0,
+                       N_("don't take whitespace into account when,\n"
                        "                             "
                        "determining where a patch should be applied")},
   {"show-diff", opt_show_diff, 0,
@@ -859,7 +859,7 @@ const svn_opt_subcommand_desc2_t svn_cl_
      "  do not agree with.\n"
      ),
     {'q', opt_dry_run, 'p', opt_reverse_diff, opt_include_pattern,
-     opt_exclude_pattern, opt_ignore_whitespaces} },
+     opt_exclude_pattern, opt_ignore_whitespace} },
 
   { "propdel", svn_cl__propdel, {"pdel", "pd"}, N_
     ("Remove a property from files, dirs, or revisions.\n"
@@ -1786,8 +1786,8 @@ main(int argc, const char *argv[])
                                                       sizeof (const char *));
         APR_ARRAY_PUSH(opt_state.exclude_patterns, const char *) = opt_arg;
         break;
-      case opt_ignore_whitespaces:
-          opt_state.ignore_whitespaces = TRUE;
+      case opt_ignore_whitespace:
+          opt_state.ignore_whitespace = TRUE;
           break;
       case opt_show_diff:
           opt_state.show_diff = TRUE;

Modified: subversion/trunk/subversion/svn/patch-cmd.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/patch-cmd.c?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/patch-cmd.c (original)
+++ subversion/trunk/subversion/svn/patch-cmd.c Sun May 23 15:39:31 2010
@@ -81,7 +81,7 @@ svn_cl__patch(apr_getopt_t *os,
                            opt_state->reverse_diff,
                            opt_state->include_patterns,
                            opt_state->exclude_patterns,
-                           opt_state->ignore_whitespaces,
+                           opt_state->ignore_whitespace,
                            TRUE, NULL, NULL, ctx, pool, pool));
 
 

Modified: subversion/trunk/subversion/tests/cmdline/merge_tests.py
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/merge_tests.py?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/merge_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/merge_tests.py Sun May 23 15:39:31 2010
@@ -3827,7 +3827,7 @@ def merge_ignore_whitespace(sbox):
   # with the remote whitespace changes as both will be ignored.
   svntest.main.file_write(file_path, "    Aa\nB b\nC c\n")
 
-  # Lines changed only by whitespaces - both in local or remote -
+  # Lines changed only by whitespace - both in local or remote -
   # should be ignored
   expected_output = wc.State(sbox.wc_dir, { file_name : Item(status='G ') })
   expected_mergeinfo_output = wc.State(sbox.wc_dir, {

Modified: subversion/trunk/subversion/tests/cmdline/patch_tests.py
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/patch_tests.py?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/patch_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/patch_tests.py Sun May 23 15:39:31 2010
@@ -2355,8 +2355,8 @@ def patch_with_include_exclude_patterns(
                                        "--include-pattern", "*a",
                                        "--exclude-pattern", "A/*/gamma")
 
-def patch_with_ignore_whitespaces(sbox):
-  "ignore whitespaces when patching"
+def patch_with_ignore_whitespace(sbox):
+  "ignore whitespace when patching"
 
   sbox.build()
   wc_dir = sbox.wc_dir
@@ -2487,7 +2487,7 @@ def patch_with_ignore_whitespaces(sbox):
                                        None, # expected err
                                        1, # check-props
                                        1, # dry-run
-                                       "--ignore-whitespaces",)
+                                       "--ignore-whitespace",)
 
 ########################################################################
 #Run the tests
@@ -2512,7 +2512,7 @@ test_list = [ None,
               patch_with_include_patterns,
               patch_with_exclude_patterns,
               patch_with_include_exclude_patterns,
-              patch_with_ignore_whitespaces,
+              patch_with_ignore_whitespace,
             ]
 
 if __name__ == '__main__':

Modified: subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c (original)
+++ subversion/trunk/subversion/tests/libsvn_diff/parse-diff-test.c Sun May 23 15:39:31 2010
@@ -64,7 +64,7 @@ test_parse_unidiff(apr_pool_t *pool)
   apr_size_t len;
   const char *fname = "test_parse_unidiff.patch";
   svn_boolean_t reverse;
-  svn_boolean_t ignore_whitespaces;
+  svn_boolean_t ignore_whitespace;
   int i;
   apr_pool_t *iterpool;
 
@@ -82,7 +82,7 @@ test_parse_unidiff(apr_pool_t *pool)
                              "Cannot write to '%s'", fname);
 
   reverse = FALSE;
-  ignore_whitespaces = FALSE;
+  ignore_whitespace = FALSE;
   iterpool = svn_pool_create(pool);
   for (i = 0; i < 2; i++)
     {
@@ -103,7 +103,7 @@ test_parse_unidiff(apr_pool_t *pool)
       /* We have two patches with one hunk each.
        * Parse the first patch. */
       SVN_ERR(svn_diff_parse_next_patch(&patch, patch_file, reverse,
-                                        ignore_whitespaces, iterpool, 
+                                        ignore_whitespace, iterpool, 
                                         iterpool));
       SVN_ERR_ASSERT(patch);
       SVN_ERR_ASSERT(! strcmp(patch->old_filename, "A/C/gamma"));
@@ -147,7 +147,7 @@ test_parse_unidiff(apr_pool_t *pool)
 
       /* Parse the second patch. */
       SVN_ERR(svn_diff_parse_next_patch(&patch, patch_file, reverse, 
-                                        ignore_whitespaces, pool, pool));
+                                        ignore_whitespace, pool, pool));
       SVN_ERR_ASSERT(patch);
       if (reverse)
         {
--- subversion/trunk/subversion/include/svn_client.h (original)
+++ subversion/trunk/subversion/include/svn_client.h Sun May 23 15:39:31 2010
@@ -4889,8 +4889,8 @@ typedef svn_error_t *(*svn_client_patch_
  * the @a include_patterns are applied first, i.e. the @a exclude_patterns
  * are applied to all targets which matched one of the @a include_patterns.
  *
  * If @a ignore_whitespaces is TRUE, allow patches to be applied if they
  * only differ from the target by whitespaces.
  *
  * If @a remove_tempfiles is TRUE, the temporary patch and reject file
  * lifetimes will be managed internally, otherwise, the caller should take
@@ -4917,7 +4917,7 @@ svn_client_patch(const char *patch_abspa
                  svn_boolean_t reverse,
                  const apr_array_header_t *include_patterns,
                  const apr_array_header_t *exclude_patterns,
-                 svn_boolean_t ignore_whitespaces,
+                 svn_boolean_t ignore_whitespace,
                  svn_boolean_t remove_tempfiles,
                  svn_client_patch_func_t patch_func,
                  void *patch_baton,
@@ -4889,8 +4889,8 @@ typedef svn_error_t *(*svn_client_patch_
  * are applied to all targets which matched one of the @a include_patterns.
  *
- * If @a ignore_whitespaces is TRUE, allow patches to be applied if they
- * only differ from the target by whitespaces.
+ * If @a ignore_whitespace is TRUE, allow patches to be applied if they
+ * only differ from the target by whitespace.
  *
  * If @a remove_tempfiles is TRUE, the temporary patch and reject file

Modified: subversion/trunk/subversion/include/svn_diff.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_diff.h?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_diff.h (original)
+++ subversion/trunk/subversion/include/svn_diff.h Sun May 23 15:39:31 2010
@@ -858,8 +858,8 @@ typedef struct svn_patch_t {
  * Return the next @a *patch in @a patch_file.
  * If no patch can be found, set @a *patch to NULL.
  * If @a reverse is TRUE, invert the patch while parsing it.
  * If @a ignore_whitespaces is TRUE, allow patches with no leading
  * whitespaces to be parsed.
  * Allocate results in @a result_pool.
  * Use @a scratch_pool for all other allocations.
  * 
@@ -868,7 +868,7 @@ svn_error_t *
 svn_diff_parse_next_patch(svn_patch_t **patch,
                           apr_file_t *patch_file,
                           svn_boolean_t reverse,
-                          svn_boolean_t ignore_whitespaces,
+                          svn_boolean_t ignore_whitespace,
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool);
 
@@ -858,8 +858,8 @@ typedef struct svn_patch_t {
  * If no patch can be found, set @a *patch to NULL.
  * If @a reverse is TRUE, invert the patch while parsing it.
- * If @a ignore_whitespaces is TRUE, allow patches with no leading
- * whitespaces to be parsed.
+ * If @a ignore_whitespace is TRUE, allow patches with no leading
+ * whitespace to be parsed.
  * Allocate results in @a result_pool.
  * Use @a scratch_pool for all other allocations.

Modified: subversion/trunk/subversion/libsvn_diff/parse-diff.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_diff/parse-diff.c?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/cl.h (original)
+++ subversion/trunk/subversion/svn/cl.h Sun May 23 15:39:31 2010
@@ -226,8 +226,8 @@ typedef struct svn_cl__opt_state_t
   svn_boolean_t reverse_diff;     /* reverse a diff (e.g. when patching) */
   apr_array_header_t *include_patterns; /* targets to include in operation */
   apr_array_header_t *exclude_patterns; /* targets to exclude from operation */
-  svn_boolean_t ignore_whitespaces; /* don't account for whitespaces when
-                                       patching */
+  svn_boolean_t ignore_whitespace; /* don't account for whitespace when
+                                      patching */
   svn_boolean_t show_diff;        /* produce diff output */
 } svn_cl__opt_state_t;
 

Modified: subversion/trunk/subversion/svn/main.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/main.c?rev=947432&r1=947431&r2=947432&view=diff
==============================================================================